# py-img-editor: image Editor in the browser written in python

## Installation
`pip install py-img-editor`

## Usage
- To start the image editor up, run `py-img-editor --start`
- Go to [http://127.0.0.1:8000/](http://127.0.0.1:8000/) to use it
- To stop it, run `py-img-editor --stop`

## Disclaimer
This is definitely a WIP. And there are probably a lot of ways I'm not following "best practices".

